@@ -84,7 +84,8 @@
       f.dir,
       f.rhs,
       all.int = TRUE,
-      binary.vec = 1:(k + k ^ 2)
+      binary.vec = 1:(k + k ^ 2),
+      scale = 0
     )$solution[1:k]
 
   return(indices_sol)
